==> bonita-common-6.1.1-sources.jar: org/bonitasoft/engine/bpm/bar/xml/CorrelationBinding.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.bar.xml;

import java.util.Map;

import org.bonitasoft.engine.bpm.flownode.impl.CorrelationDefinitionImpl;
import org.bonitasoft.engine.expression.Expression;
import org.bonitasoft.engine.io.xml.ElementBinding;

/**
 * @author Elias Ricken de Medeiros
 */
public class CorrelationBinding extends ElementBinding {

    private Expression key;

    private Expression value;

    public CorrelationBinding() {
        super();
    }

    @Override
    public String getElementTag() {
        return XMLProcessDefinition.CORRELATION_NODE;
    }

    @Override
    public void setAttributes(final Map<String, String> attributes) {
    }

    @Override
    public void setChildElement(final String name, final String value, final Map<String, String> attributes) {
    }

    @Override
    public void setChildObject(final String name, final Object value) {
        if (XMLProcessDefinition.CORRELATION_KEY.equals(name)) {
            key = (Expression) value;
        }
        if (XMLProcessDefinition.CORRELATION_VALUE.equals(name)) {
            this.value = (Expression) value;
        }
    }

    @Override
    public Object getObject() {
        return new CorrelationDefinitionImpl(key, value);
    }

}

==> bonita-common-6.3.1-sources.jar: org/bonitasoft/engine/bpm/bar/xml/CorrelationBinding.java <==
/**
 * Copyright (C) 2011 BonitaSoft S.A.
 * BonitaSoft, 32 rue Gustave Eiffel - 38000 Grenoble
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA 02110-1301, USA.
 **/
package org.bonitasoft.engine.bpm.bar.xml;

import java.util.Map;

import org.bonitasoft.engine.bpm.flownode.impl.internal.CorrelationDefinitionImpl;
import org.bonitasoft.engine.expression.Expression;
import org.bonitasoft.engine.io.xml.ElementBinding;

/**
 * @author Elias Ricken de Medeiros
 */
public class CorrelationBinding extends ElementBinding {

    private Expression key;

    private Expression value;

    public CorrelationBinding() {
        super();
    }

    @Override
    public String getElementTag() {
        return XMLProcessDefinition.CORRELATION_NODE;
    }

    @Override
    public void setAttributes(final Map<String, String> attributes) {
    }

    @Override
    public void setChildElement(final String name, final String value, final Map<String, String> attributes) {
    }

    @Override
    public void setChildObject(final String name, final Object value) {
        if (XMLProcessDefinition.CORRELATION_KEY.equals(name)) {
            key = (Expression) value;
        }
        if (XMLProcessDefinition.CORRELATION_VALUE.equals(name)) {
            this.value = (Expression) value;
        }
    }

    @Override
    public Object getObject() {
        return new CorrelationDefinitionImpl(key, value);
    }

}
